fw: rename "Interest rebuff" to "Interest reject"

Change-Id: I8275354a3eff6f4785187a8fb00da1d421df8460
diff --git a/daemon/fw/strategy.hpp b/daemon/fw/strategy.hpp
index 311af93..edffdb3 100644
--- a/daemon/fw/strategy.hpp
+++ b/daemon/fw/strategy.hpp
@@ -43,7 +43,7 @@
    *  - If the strategy decides to forward this Interest,
    *    invoke this->sendInterest one or more times, either now or shortly after
    *  - If strategy concludes that this Interest cannot be forwarded,
    *    invoke this->rebuffPendingInterest so that PIT entry will be deleted shortly
    */
   virtual void
   afterReceiveInterest(const Face& inFace,
@@ -106,7 +106,7 @@
    *  forwarded earlier, and does not need to be resent now.
    */
   VIRTUAL_WITH_TESTS void
-  rebuffPendingInterest(shared_ptr<pit::Entry> pitEntry);
+  rejectPendingInterest(shared_ptr<pit::Entry> pitEntry);
 
 protected: // accessors
   MeasurementsAccessor&
@@ -43,7 +43,7 @@
    *    invoke this->sendInterest one or more times, either now or shortly after
    *  - If strategy concludes that this Interest cannot be forwarded,
-   *    invoke this->rebuffPendingInterest so that PIT entry will be deleted shortly
+   *    invoke this->rejectPendingInterest so that PIT entry will be deleted shortly
    */
   virtual void